// SPDX-License-Identifier: LGPL-2.1-or-later
#ifndef __ORG_KERNEL_HINAWA_H__
#define __ORG_KERNEL_HINAWA_H__

#include <glib.h>
#include <glib-object.h>

#include <linux/firewire-cdev.h>
#include <linux/firewire-constants.h>
#include <sound/firewire.h>

#include <hinawa_sigs_marshal.h>

#include <hinawa_enum_types.h>
#include <hinawa_enums.h>

#include <cycle_time.h>

#include <fw_node.h>
#include <fw_resp.h>
#include <fw_req.h>
#include <fw_fcp.h>

#endif
